==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/WebSliderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNumberEventArgsDescriptionMetadata } from "./WebNumberEventArgsDescriptionMetadata";
import { WebSliderBaseDescriptionMetadata } from "./WebSliderBaseDescriptionMetadata";
import { WebSliderDescription } from "./WebSliderDescription";
/**
 * @hidden
 */
var WebSliderDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebSliderDescriptionMetadata, _super);
    function WebSliderDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSliderDescriptionMetadata.b = function (a) {
        if (WebSliderDescriptionMetadata.a == null) {
            WebSliderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSliderDescriptionMetadata.c(WebSliderDescriptionMetadata.a);
        }
        if (a.g(WebSliderDescriptionMetadata.a)) {
            return;
        }
        a.s(WebSliderDescriptionMetadata.a);
        WebNumberEventArgsDescriptionMetadata.d(a);
    };
    WebSliderDescriptionMetadata.c = function (a) {
        WebSliderBaseDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:Slider");
        a.item("Value", "Number:double");
        a.item("AriaLabel", "String");
        a.item("InputRef", "EventRef::input");
        a.item("ChangeRef", "EventRef::change");
    };
    WebSliderDescriptionMetadata.d = function (a) {
        WebSliderDescriptionMetadata.b(a);
        a.u("WebSlider", function () { return new WebSliderDescription(); });
        a.t("WebSlider", WebSliderDescriptionMetadata.a);
    };
    WebSliderDescriptionMetadata.$t = markType(WebSliderDescriptionMetadata, 'WebSliderDescriptionMetadata');
    WebSliderDescriptionMetadata.a = null;
    return WebSliderDescriptionMetadata;
}(Base));
export { WebSliderDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebSliderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNumberEventArgsDescriptionMetadata } from "./WebNumberEventArgsDescriptionMetadata";
import { WebSliderBaseDescriptionMetadata } from "./WebSliderBaseDescriptionMetadata";
import { WebSliderDescription } from "./WebSliderDescription";
/**
 * @hidden
 */
var WebSliderDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebSliderDescriptionMetadata, _super);
    function WebSliderDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSliderDescriptionMetadata.b = function (a) {
        if (WebSliderDescriptionMetadata.a == null) {
            WebSliderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSliderDescriptionMetadata.c(WebSliderDescriptionMetadata.a);
        }
        if (a.j(WebSliderDescriptionMetadata.a)) {
            return;
        }
        a.y(WebSliderDescriptionMetadata.a);
        WebNumberEventArgsDescriptionMetadata.d(a);
    };
    WebSliderDescriptionMetadata.c = function (a) {
        WebSliderBaseDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:Slider");
        a.item("__tagNameWC", "String:igc-slider");
        a.item("Value", "Number:double");
        a.item("AriaLabel", "String");
        a.item("InputRef", "EventRef::input");
        a.item("ChangeRef", "EventRef::change");
    };
    WebSliderDescriptionMetadata.d = function (a) {
        WebSliderDescriptionMetadata.b(a);
        a.aa("WebSlider", function () { return new WebSliderDescription(); });
        a.z("WebSlider", WebSliderDescriptionMetadata.a);
    };
    WebSliderDescriptionMetadata.$t = markType(WebSliderDescriptionMetadata, 'WebSliderDescriptionMetadata');
    WebSliderDescriptionMetadata.a = null;
    return WebSliderDescriptionMetadata;
}(Base));
export { WebSliderDescriptionMetadata };
